<?php

declare(strict_types=1);

namespace Drupal\Tests\cqri\Functional;

use Drupal\Tests\image\Functional\ImageFieldTestBase;
use Drupal\Tests\TestFileCreationTrait;
use PHPUnit\Framework\Attributes\Group;

/**
 * Test description.
 */
#[Group('cqri')]
class CqriFunctionalTest extends ImageFieldTestBase {

  use TestFileCreationTrait;

  /**
   * {@inheritdoc}
   */
  protected $defaultTheme = 'stark';

  /**
   * {@inheritdoc}
   */
  protected static $modules =
    [
      'cqri',
      'node',
      'image',
      'field_ui',
      'image_module_test',
      'responsive_image',
    ];

  /**
   * {@inheritdoc}
   */
  protected function setUp(): void {
    parent::setUp();

    $this->setUpContentType();

    $this->setTestNode();
  }

  /**
   * Test callback.
   */
  public function testCqri(): void {

    $this->drupalGet('node/1');
    $this->assertSession()->responseContains('<container-picture>');

  }

  /**
   * Setup Article content Type.
   */
  protected function setUpContentType(): void {

    $storage_settings = ['file_extensions' => 'png jpg gif'];
    $this->createImageField('field_img', 'node', 'article', $storage_settings);

    $formatter_settings = [
      'type' => 'container_queries_responsive_image',
      'settings' => [
        'image_link' => FALSE,
        'responsive_image_style' => 'container_query',
      ],
    ];
    /** @var \Drupal\Core\Entity\EntityDisplayRepositoryInterface $display_repository */
    $display_repository = \Drupal::service('entity_display.repository');
    $display = $display_repository->getViewDisplay('node', 'article');
    $display->setComponent('field_img', $formatter_settings)
      ->save();

  }

  /**
   * Setup Test node.
   */
  protected function setTestNode(): void {
    /** @var \stdClass $test_image */
    $test_image = current($this->getTestFiles('image', 39325));
    $this->uploadNodeImage($test_image, 'field_img', 'article', 'CQRI Test');
  }

}
